==> spellathon-5.47.tar.gz: spellathon-5.47/src/gui/help.cc <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#include <QTextEdit>
#include <QVBoxLayout>
#include <QPushButton>
#include <QShowEvent>

#include "help.h"
#include "../logic/defines.h"

Help::Help(QWidget *p) : QDialog(p), parent(p)
{
	QTextEdit *txt		= new QTextEdit(this);
	QPushButton *ok		= new QPushButton(this);
	QVBoxLayout *layout	= new QVBoxLayout(this);
	
	connect(ok, SIGNAL(clicked()), this, SLOT(close()));

	resize(380, 500);
	setWindowTitle("Spellathon Help");
	layout->addWidget(txt);
	layout->addWidget(ok, 0, Qt::AlignCenter);
	ok->setText("&Ok");
	txt->setReadOnly(true);
	txt->setLineWrapMode(QTextEdit::WidgetWidth);
	txt->setHtml(
		QString("<br><b>Game instructions</b><br><br><font color=\"darkblue\">"
		   "Find all the words of four or more letters"
		   " from the letters shown in the puzzle.<br><br>"
		   "In making a word, each letter may be used "
		   "once only.<br><br>Each word must contain the "
		   "central letter.<br><br>There should be atleast"
		   " one seven letter word.<br><br>Plurals, foreign words and"
		   " proper names are not allowed.<br></font>"
		   "<br><br><b>Notes</b><br><br><font color=\"#404040\">"
		   "Ratings: %1, %2, %3, %4.<br><br>"
		   "Using hints will reduce your score.<br><br>"
		   "To get the top scores you will "
		   "need to be fast.<br><br>"
		   "The seven letter word(s) is worth extra points<br><br>"
		   "To solve a custom puzzle enter the letters of puzzle "
		   "in the corresponding boxes and press Solve.<br></font>"
		   ).arg(Ratings[0]).arg(Ratings[1]).arg(Ratings[2]).arg(Ratings[3])
	);
}

void
Help::showEvent(QShowEvent *ev)
{
	move(parent->pos().x() + parent->frameSize().width(), parent->pos().y());
	ev->accept();
}

==> spellathon-5.53.tar.gz: spellathon-5.53/src/gui/help.cc <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#include <QTextEdit>
#include <QVBoxLayout>
#include <QPushButton>
#include <QShowEvent>

#include "help.h"
#include "../logic/defines.h"

Help::Help(QWidget *p) : QDialog(p), parent(p)
{
	QTextEdit *txt		= new QTextEdit(this);
	QPushButton *ok		= new QPushButton(this);
	QVBoxLayout *layout	= new QVBoxLayout(this);
	
	connect(ok, SIGNAL(clicked()), this, SLOT(close()));

	resize(380, 500);
	setWindowTitle("Spellathon Help");
	layout->addWidget(txt);
	layout->addWidget(ok, 0, Qt::AlignCenter);
	ok->setText("&Ok");
	txt->setReadOnly(true);
	txt->setLineWrapMode(QTextEdit::WidgetWidth);
	txt->setHtml(
		QString("<br><b>Game instructions</b><br><br><font color=\"darkblue\">"
		   "Find all the words of four or more letters"
		   " from the letters shown in the puzzle.<br><br>"
		   "In making a word, each letter may be used "
		   "once only.<br><br>Each word must contain the "
		   "central letter.<br><br>There should be atleast"
		   " one seven letter word.<br><br>Plurals, foreign words and"
		   " proper names are not allowed.<br></font>"
		   "<br><br><b>Notes</b><br><br><font color=\"#404040\">"
		   "Ratings: %1, %2, %3.<br><br>"
		   "Using hints will reduce your score.<br><br>"
		   "To get the top scores you will "
		   "need to be fast.<br><br>"
		   "The seven letter word(s) is worth extra points.<br><br>"
		   "To solve a custom puzzle enter the letters of puzzle "
		   "in the corresponding boxes and press Solve.<br></font>"
		   ).arg(Ratings[1]).arg(Ratings[2]).arg(Ratings[3])
	);
}

void
Help::showEvent(QShowEvent *ev)
{
	move(parent->pos().x() + parent->frameSize().width(), parent->pos().y());
	ev->accept();
}
